Precise times and durations using 64bit primitives and whole nanoseconds.
Unlike std::time, these types always have a fixed size representation and
also includes atomic types.
Structs
- Atomic
Duration - An atomic duration measured in nanoseconds.
- Atomic
Instant - An atomic precise measurement of a monotonically nodecreasing clock.
- Atomic
Unix Instant - An atomic precise measurement of the system clock.
- Duration
- A duration measured in nanoseconds.
- Instant
- A measurement of a monotonically nodecreasing clock in nanoseconds.
- Unix
Instant - A measurement of the system clock in nanoseconds.